CheckedNumOps

Trait CheckedNumOps 

pub trait CheckedNumOps:
    CheckedAdd
    + CheckedSub
    + CheckedMul
    + CheckedDiv
    + CheckedRem
    + CheckedNeg { }
Traits for basic checked numeric operations that returns None on overflow.

This trait is implemented for all the types that implements the traits.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors